==> bluefish_0.3.5.orig.tar.gz: bluefish-0.3.5/src/toolbars.h <==
/* Bluefish HTML Editor
 * toolbars.h - toolbar stuff (neat huh?)
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TOOLBARS_H_
#define __TOOLBARS_H_

#include <glib.h>
#include <gtk/gtkwidget.h>
#include <gdk/gdktypes.h>

void get_main_menu (GtkWidget * window, GtkWidget ** menubar);
void toggle_html_toolbar(GtkWidget * w, gpointer data);
void toggle_main_toolbar(GtkWidget * w, gpointer data);
void toggle_cust_menubar(GtkWidget * w, gpointer data);
void show_html_toolbar(GtkWidget * w, gpointer data);
void show_main_toolbar(GtkWidget * w, gpointer data);
void hide_html_toolbar(GtkWidget * w, gpointer data);
void hide_main_toolbar(GtkWidget * w, gpointer data);
void show_cust_menubar(GtkWidget * w, gpointer data);
void hide_cust_menubar(GtkWidget * w, gpointer data);
GtkWidget *new_pixmap(int type, GdkWindow * window, GdkColor * background);
void insert_char(GtkWidget * widget, gint data);

#endif	/* __TOOLBARS_H_ */

==> bluefish-0.3.6.tar.gz: bluefish-0.3.6/src/toolbars.h <==
/* Bluefish HTML Editor
 * toolbars.h - toolbar stuff (neat huh?)
 *
 * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __TOOLBARS_H_
#define __TOOLBARS_H_

#include <glib.h>
#include <gtk/gtkwidget.h>
#include <gdk/gdktypes.h>

void get_main_menu(GtkWidget * window, GtkWidget ** menubar);
void show_html_toolbar_cb(GtkWidget * w, gpointer data);
void show_main_toolbar_cb(GtkWidget * w, gpointer data);
void hide_html_toolbar_cb(GtkWidget * w, gpointer data);
void hide_main_toolbar_cb(GtkWidget * w, gpointer data);
GtkWidget *new_pixmap(int type, GdkWindow * window, GdkColor * background);
void insert_char_cb(GtkWidget * widget, gint data);
void toggle_main_toolbar_lcb(GtkWidget * w, gpointer data);
void toggle_html_toolbar_lcb(GtkWidget * w, gpointer data);

#endif							/* __TOOLBARS_H_ */
